@@ -1,6 +1,8 @@
 #line 1 "inc/Module/Install/MakeMaker.pm - E:/Perl/site/lib/Module/Install/MakeMaker.pm"
 package Module::Install::MakeMaker;
-use Module::Install::Base; @ISA = qw(Module::Install::Base);
+
+use Module::Install::Base;
+@ISA = qw(Module::Install::Base);
 
 $VERSION = '0.01';
 
