@@ -1,42 +1,39 @@
 #line 1 "inc/Module/Install/Metadata.pm - E:/Perl/site/lib/Module/Install/Metadata.pm"
 package Module::Install::Metadata;
-use Module::Install::Base;
-@ISA = qw(Module::Install::Base);
 
-$VERSION = '0.04';
+use Module::Install::Base;
+@ISA = qw{Module::Install::Base};
+
+$VERSION = '0.06';
 
 use strict 'vars';
-use vars qw($VERSION);
 
-sub Meta { shift }
-
-my @scalar_keys = qw<
-    name module_name version abstract author license
+my @scalar_keys = qw{
+    name module_name abstract author version license
     distribution_type perl_version tests
->;
-my @tuple_keys = qw<
+};
+
+my @tuple_keys = qw{
     build_requires requires recommends bundles
->;
+};
+
+sub Meta            { shift        }
+sub Meta_ScalarKeys { @scalar_keys }
+sub Meta_TupleKeys  { @tuple_keys  }
 
 foreach my $key (@scalar_keys) {
     *$key = sub {
         my $self = shift;
-        return $self->{'values'}{$key} unless @_;
-        $self->{'values'}{$key} = shift;
+        return $self->{values}{$key} if defined wantarray and !@_;
+        $self->{values}{$key} = shift;
         return $self;
     };
 }
 
-sub sign {
-    my $self = shift;
-    $self->{'values'}{'sign'} = ( @_ ? $_[0] : 1 );
-    return $self;
-}
-
 foreach my $key (@tuple_keys) {
     *$key = sub {
         my $self = shift;
-        return $self->{'values'}{$key} unless @_;
+        return $self->{values}{$key} unless @_;
 
         my @rv;
         while (@_) {
@@ -51,14 +48,29 @@ foreach my $key (@tuple_keys) {
             my $rv = [ $module, $version ];
             push @rv, $rv;
         }
-        push @{ $self->{'values'}{$key} }, @rv;
+        push @{ $self->{values}{$key} }, @rv;
         @rv;
     };
 }
 
+sub sign {
+    my $self = shift;
+    return $self->{'values'}{'sign'} if defined wantarray and !@_;
+    $self->{'values'}{'sign'} = ( @_ ? $_[0] : 1 );
+    return $self;
+}
+
 sub all_from {
     my ( $self, $file ) = @_;
 
+    unless ( defined($file) ) {
+        my $name = $self->name
+            or die "all_from called with no args without setting name() first";
+        $file = join('/', 'lib', split(/-/, $name)) . '.pm';
+        $file =~ s{.*/}{} unless -e $file;
+        die "all_from: cannot find $file from $name" unless -e $file;
+    }
+
     $self->version_from($file)      unless $self->version;
     $self->perl_version_from($file) unless $self->perl_version;
 
@@ -76,7 +88,7 @@ sub all_from {
 
 sub provides {
     my $self     = shift;
-    my $provides = ( $self->{'values'}{'provides'} ||= {} );
+    my $provides = ( $self->{values}{provides} ||= {} );
     %$provides = (%$provides, @_) if @_;
     return $provides;
 }
@@ -90,6 +102,12 @@ sub auto_provides {
         return $self;
     }
 
+    # Avoid spurious warnings as we are not checking manifest here.
+
+    local $SIG{__WARN__} = sub {1};
+    require ExtUtils::Manifest;
+    local *ExtUtils::Manifest::manicheck = sub { return };
+
     require Module::Build;
     my $build = Module::Build->new(
         dist_name    => $self->{name},
@@ -102,7 +120,7 @@ sub auto_provides {
 sub feature {
     my $self     = shift;
     my $name     = shift;
-    my $features = ( $self->{'values'}{'features'} ||= [] );
+    my $features = ( $self->{values}{features} ||= [] );
 
     my $mods;
 
@@ -134,84 +152,14 @@ sub features {
     while ( my ( $name, $mods ) = splice( @_, 0, 2 ) ) {
         $self->feature( $name, @$mods );
     }
-    return @{ $self->{'values'}{'features'} };
+    return @{ $self->{values}{features} };
 }
 
 sub no_index {
     my $self = shift;
     my $type = shift;
-    push @{ $self->{'values'}{'no_index'}{$type} }, @_ if $type;
-    return $self->{'values'}{'no_index'};
-}
-
-sub _dump {
-    my $self    = shift;
-    my $package = ref( $self->_top );
-    my $version = $self->_top->VERSION;
-    my %values  = %{ $self->{'values'} };
-
-    delete $values{sign};
-    if ( my $perl_version = delete $values{perl_version} ) {
-
-        # Always canonical to three-dot version
-        $perl_version =~
-          s{^(\d+)\.(\d\d\d)(\d*)}{join('.', $1, int($2), int($3))}e
-          if $perl_version >= 5.006;
-        $values{requires} =
-          [ [ perl => $perl_version ], @{ $values{requires} || [] }, ];
-    }
-
-    warn "No license specified, setting license = 'unknown'\n"
-      unless $values{license};
-
-    $values{license}           ||= 'unknown';
-    $values{distribution_type} ||= 'module';
-    $values{name}              ||= do {
-        my $name = $values{module_name};
-        $name =~ s/::/-/g;
-        $name;
-    } if $values{module_name};
-
-    if ( $values{name} =~ /::/ ) {
-        my $name = $values{name};
-        $name =~ s/::/-/g;
-        die "Error in name(): '$values{name}' should be '$name'!\n";
-    }
-
-    my $dump = '';
-    foreach my $key (@scalar_keys) {
-        $dump .= "$key: $values{$key}\n" if exists $values{$key};
-    }
-    foreach my $key (@tuple_keys) {
-        next unless exists $values{$key};
-        $dump .= "$key:\n";
-        foreach ( @{ $values{$key} } ) {
-            $dump .= "  $_->[0]: $_->[1]\n";
-        }
-    }
-
-    if ( my $provides = $values{provides} ) {
-        require YAML;
-        local $YAML::UseHeader = 0;
-        $dump .= YAML::Dump( { provides => $provides } );
-    }
-
-    if ( my $no_index = $values{no_index} ) {
-        push @{ $no_index->{'directory'} }, 'inc';
-        require YAML;
-        local $YAML::UseHeader = 0;
-        $dump .= YAML::Dump( { no_index => $no_index } );
-    }
-    else {
-        $dump .= << "META";
-no_index:
-  directory:
-    - inc
-META
-    }
-
-    $dump .= "generated_by: $package version $version\n";
-    return $dump;
+    push @{ $self->{values}{no_index}{$type} }, @_ if $type;
+    return $self->{values}{no_index};
 }
 
 sub read {
@@ -239,24 +187,7 @@ sub read {
 sub write {
     my $self = shift;
     return $self unless $self->is_admin;
-
-  META_NOT_OURS: {
-        local *FH;
-        if ( open FH, "META.yml" ) {
-            while (<FH>) {
-                last META_NOT_OURS if /^generated_by: Module::Install\b/;
-            }
-            return $self if -s FH;
-        }
-    }
-
-    print "Writing META.yml\n";
-
-    local *META;
-    open META, "> META.yml" or warn "Cannot write to META.yml: $!";
-    print META $self->_dump;
-    close META;
-
+    $self->admin->write_meta;
     return $self;
 }
 
@@ -270,8 +201,11 @@ sub abstract_from {
     my ( $self, $file ) = @_;
     require ExtUtils::MM_Unix;
     $self->abstract(
-        bless( { DISTNAME => $self->name }, 'ExtUtils::MM_Unix' )
-          ->parse_abstract($file) );
+        bless(
+            { DISTNAME => $self->name },
+            'ExtUtils::MM_Unix'
+        )->parse_abstract($file)
+     );
 }
 
 sub _slurp {
